@@ -1,26 +1,8 @@
 package SQL::Translator::Parser;
 
-# ----------------------------------------------------------------------
-# Copyright (C) 2002-2009 SQLFairy Authors
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-# 02111-1307  USA
-# ----------------------------------------------------------------------
-
 use strict;
-use vars qw( $VERSION );
-$VERSION = '1.59';
+use warnings;
+our $VERSION = '1.60';
 
 sub parse { "" }
 
@@ -60,7 +42,7 @@ source code for existing SQL::Translator::Parser::* modules.
 
 =head1 AUTHORS
 
-Ken Y. Clark, E<lt>kclark@cpan.org<gt>, 
+Ken Youens-Clark, E<lt>kclark@cpan.org<gt>,
 darren chamberlain E<lt>darren@cpan.orgE<gt>.
 
 =head1 SEE ALSO
